import unittest
from smufolib.request import Request, URLWarning

# pylint: disable=C0115, C0116, C0103


class RequestTest(unittest.TestCase):

    def test_json(self):
        pass

    def test_raw(self):
        pass

    def test_path(self):
        pass

    def test_fallback(self):
        pass

    def test_mode(self):
        pass

    def test_encoding(self):
        pass


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python3
# coding: utf-8
# pylint: disable=C0301
"""
This script generates a full featured metadata `JSON
<https://www.json.org/json-en.html>`_ file for SMuFL fonts from
metadata sources and user specifications, including the following
metadata sections:

    * `mandatory (fontName and fontVersion)
      <https://w3c.github.io/smufl/latest/specification/font-specific-metadata.html>`_
    * `size <https://w3c.github.io/smufl/latest/specification/font-specific-metadata.html>`_
    * `engravingDefaults <https://w3c.github.io/smufl/latest/specification/engravingdefaults.html>`_
    * `glyphAdvanceWidths <https://w3c.github.io/smufl/latest/specification/glyphadvancewidths.html>`_
    * `glyphsWithAnchors <https://w3c.github.io/smufl/latest/specification/glyphswithanchors.html>`_
    * `glyphsWithAlternates <https://w3c.github.io/smufl/latest/specification/glyphswithalternates.html>`_
    * `glyphBBoxes <https://w3c.github.io/smufl/latest/specification/glyphbboxes.html>`_
    * `ligatures <https://w3c.github.io/smufl/latest/specification/ligatures.html>`_
    * `sets <https://w3c.github.io/smufl/latest/specification/sets.html>`_
    * `optionalGlyphs <https://w3c.github.io/smufl/latest/specification/optionalglyphs.html>`_

Sections are automatically added depending on the font's scope and
assigned attribute values.

.. tip:: As a starting point, identification and engraving defaults
   attributes may be set automatically with the :mod:`~bin.importID`
   and :mod:`~bin.calculateEngravingDefaults` scripts respectively.

This script requires that SMufoLib be installed within its executive
environment. It may also be imported as a module and contains the
following public functions:

    * :func:`generateMetadata` – The scripts program function.
    * :func:`main` - Command line entry point.

"""
from __future__ import annotations
from typing import Any
import argparse
import collections
from pathlib import Path

from tqdm import tqdm

from smufolib import Font, cli, config, stdUtils
from smufolib.request import Request, writeJson

CONFIG = config.load()

# Parameter defaults
FONT_DATA = Request(CONFIG['metadata.paths']['referenceFont'],
                    CONFIG['metadata.fallbacks']['referenceFont'])
VERBOSE = False

# pylint: disable=C0103


def generateMetadata(font: Font | Path | str,
                     targetPath: str | Path,
                     fontData: str | Path | Request = FONT_DATA,
                     verbose: bool = VERBOSE) -> None:
    """Generate metadata JSON file.

    :param font: Object or path to
        targetPath :class:`~smufolib.objects.font.Font`.
    :param targetPath: Target directory for Metadata JSON file.
    :param verbose: Make output verbose. Defaults to :obj:`False`.

    """
    # Check if targetPath exists.
    if not Path(targetPath).exists():
        raise FileNotFoundError("Target path does not exist.")

    # Convert font path to object.
    font = font if isinstance(font, Font) else Font(font)
    font.smufl.spaces = True

    # Define print function to be do-nothing if verbose=False.
    verboseprint = print if verbose else lambda *a, **k: None

    metadata = _compileMetadata(font, fontData, verbose, verboseprint)
    filename = Path(targetPath).resolve() / f'{font.smufl.name}.json'

    verboseprint("Writing metadata to:", filename)
    writeJson(filename, metadata)

    print("Done!")


def main():
    """Command line entry point."""
    args = _parseArgs()
    generateMetadata(args.font,
                     args.targetPath,
                     fontData=args.fontData,
                     verbose=args.verbose)


def _compileMetadata(font, fontData, verbose, verboseprint) -> dict[str, Any]:
    # Build SMuFL-specific metadata dictionary.
    # pylint: disable=R0912, R0914

    print("Compiling metadata...")

    metadata = collections.defaultdict(dict)

    keys = ('fontName', 'fontVersion', 'designSize',
            'sizeRange', 'engravingDefaults')

    for key in keys:
        attribute = key[4:].lower() if 'font' in key else key
        value = getattr(font.smufl, attribute)
        if attribute == 'engravingDefaults':
            value = value.items()
        elif value is None:
            continue
        metadata[key] = value

    sets, setglyphs = {}, []
    setsTemplate = _getSetsTemplate(fontData)
    attributes = ('name', 'unicode')
    # Set up progress bar if verbose is True
    font = font if verbose else tqdm(font)
    # skipped = []

    for glyph in font:
        if not glyph or not stdUtils.validateClassAttr(glyph, attributes):
            verboseprint("Skipping unnamed or unencoded glyph:", glyph)
            continue

        s = glyph.smufl
        metadata['glyphAdvanceWidths'][s.name] = s.advanceWidth
        metadata['glyphBBoxes'][s.name] = s.bBox

        if s.alternates:
            baseglyphs = {}
            baseglyphs['alternates'] = s.alternates
            metadata['glyphsWithAlternates'][s.name] = baseglyphs

        if s.anchors:
            metadata['glyphsWithAnchors'][s.name] = s.anchors

        if s.isLigature:
            metadata['ligatures'][s.name] = {}
            metadata['ligatures'][s.name]["codepoint"] = s.codepoint
            if s.componentGlyphs:
                metadata['ligatures'][s.name]['componentGlyphs'] = s.componentGlyphs
            metadata['ligatures'][s.name]["description"] = s.description

        if s.isOptional:
            metadata['optionalGlyphs'][s.name] = {}
            metadata['optionalGlyphs'][s.name]['codepoint'] = s.codepoint
            metadata['optionalGlyphs'][s.name]['description'] = s.description
            metadata['optionalGlyphs'][s.name]['classes'] = s.classes

        if s.isSet:
            sets[s.suffix] = setsTemplate[s.suffix]
            glyphinfo = {"alternateFor": s.base.name,
                         "codepoint": s.codepoint,
                         "description": s.description,
                         "name": s.name}
            setglyphs.append(glyphinfo)
            metadata['sets'] = sets
            metadata['sets'][s.suffix]['glyphs'] = setglyphs

    return metadata


def _getSetsTemplate(fontData) -> dict[str, dict[str, str]]:
    # Extract sets template from bravura_metadata.json.
    sets = {}

    try:
        fontData = fontData.json()
    except AttributeError:
        Request(fontData).json()
    for key, values in fontData['sets'].items():
        sets[key] = {}
        for subKey, value in values.items():
            if subKey not in ('description', 'type'):
                continue
            sets[key][subKey] = value
    return sets


def _parseArgs() -> argparse.Namespace:
    # Parse command line arguments and options.
    parser = cli.commonParser('font',
                              'targetPath',
                              addHelp=True,
                              description="Generate font metadata JSON file.",
                              fontData=FONT_DATA,
                              verbose=VERBOSE)

    return parser.parse_args()


if __name__ == '__main__':
    main()



from __future__ import annotations
from typing import Any
from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
import json

from smufolib import config, converters
from smufolib.objects.font import Font
from smufolib.request import Request

CONFIG = config.load()

# pylint: disable=invalid-name, unused-argument, too-many-branches


#: Available arguments and their settings.
CLI_ARGUMENTS: dict[str, dict[str, Any]] = {
    'attributes': {
        'nargs': '+',
        'help': "Attribute names to include in processing."
    },
    'classesData': {
        'type': Request,
        'help': "Path to classes metadata file."
    },
    'clear': {
        'action': 'store_true',
        'help': "Erase preexisting objects on execution."
    },
    'color': {
        'nargs': 4,
        'type': converters.toNumber,
        'help': "List of RGBA color values."
    },
    'colors': {
        'type': json.loads,
        'help': "Keys mapped to RGBA color arrays as JSON string."
    },
    'exclude': {
        'nargs': '+',
        'help': "Objects to exclude from processing."
    },
    'font': {
        'type': Font,
        'help': "Path to UFO file."
    },
    'fontData': {
        'type': Request,
        'help': "Path to font metadata file."
    },
    'glyphnamesData': {
        'type': Request,
        'help': "Path to glyphnames metadata file."
    },
    'include': {
        'nargs': '+',
        'help': "Objects to include in processing."
    },
    'includeOptionals': {
        'action': 'store_true',
        'help': "Include optional glyphs."
    },
    'mark': {
        'action': 'store_true',
        'help': "Apply defined color values to objects."
    },
    'overwrite': {
        'action': 'store_true',
        'help': "Overwrite preexisting values."
    },
    'rangesData': {
        'type': Request,
        'help': "Path to ranges metadata file."
    },
    'sourcePath': {
        'type': Request,
        'help': "Path to source file or directory."
    },
    'spaces': {
        'action': 'store_true',
        'help': "Set measurement unit to staff spaces."
    },
    'targetPath': {
        'help': "Path to target file or directory."
    },
    'verbose': {
        'action': 'store_true',
        'help': "Make output verbose."
    }
}


def commonParser(*args, addHelp: bool = False, description: str | None = None,
                 customHelpers: dict[str] = None, **kwargs) -> ArgumentParser:
    r"""Provide generic command-line arguments and options.

    See the :ref:`Available Options` for details.

    :param \*args: Required positional arguments to assign.
    :param addHelp: Add help message. Should be :obj:`False` when
        function is parent and otherwise :obj:`True`. Defaults to False.
    :param description: Program description when used directly. Defaults
        to :obj:`None`
    :param customHelpers: arguments mapped to custom help strings to
        override the default. Defaults to :obj:`None`
    :param \**kwargs: Options and their default values to assign.
    :raises TypeError: Duplicate arguments in \*args and \**kwargs.

    Examples::

        >>> import argparse
        >>> from smufolib import Font, cli
        >>> args = cli.commonParser('font', clear=True)
        >>> parser = argparse.ArgumentParser(parents=[args],
        ...             description='showcase commonParser')
        >>> parser.add_argument(
        ...     '-O', '--include-optionals',
        ...     action='store_true',
        ...     default=includeOptionals,
        ...     help="include optional glyphs",
        ...     dest='includeOptionals'
        ... )
        >>> parser.parse_args("-h".split()))
        usage: test.py [-h] [-x] [-O] font

        showcase commonParser

        positional arguments:
            font         path to UFO file

        optional arguments:
            -h, --help                show this help message and exit
            -x, --clear               erase preexisting objects on execution
            -O, --include-optionals   include optional glyphs

    ::

        >>> parser.parse_args("-f path/to/my/font.ufo".split())
        Namespace(font=<Font 'MyFont' path='path/to/my/font.ufo' at 4377107232>, mark=False)

    ::

        >>> parser.parse_args("-f path/to/my/font.ufo --clear".split())
        Namespace(font=<Font 'MyFont' path='path/to/my/font.ufo' at 4377107232>, mark=True)

    """

    parser = ArgumentParser(add_help=addHelp,
                            formatter_class=ArgumentDefaultsHelpFormatter,
                            description=description)

    for arg in args:
        CLI_ARGUMENTS[arg]['metavar'] = converters.toKebab(arg)
        parser.add_argument(arg, **CLI_ARGUMENTS[arg])

    seen = set()
    for key, value in kwargs.items():
        if key in args:
            raise TypeError(
                f"Option '{key}' is already added as positional argument.")

        flags = _generateFlags(key)
        assert flags[0] not in seen, f"Short flag '{flags[0]}' is duplicate."
        seen.add(flags[0])

        CLI_ARGUMENTS[key]['dest'] = key
        if value is not None:
            CLI_ARGUMENTS[key]['default'] = value
        parser.add_argument(*flags, **CLI_ARGUMENTS[key])
    return parser


def _generateFlags(argument):
    # Generates tuple of option flags.
    shortFlags = CONFIG['cli.shortFlags']
    longFlag = f'--{converters.toKebab(argument)}'
    return (shortFlags[argument], longFlag)



import unittest
from smufolib.pointUtils import (
    Point,
    Position,
    getPoints,
    getContourPoints,
    getCompositePoints
)

# pylint: disable=C0115, C0116, C0103


class PointUtils(unittest.TestCase):

    def setUp(self):
        self.position1 = Position(0.0, 0.0)
        self.position2 = Position(0.0, 0.0)
        self.position3 = Position(0.0, 0.0)
        self.point1 = Point(self.position1, 'line', 0)
        self.point2 = Point(self.position2, 'curve', 0)
        self.point3 = Point(self.position2, 'qcurve', 0)

    def tearDown(self):
        pass

    def test_getPoints(self):
        pass

    def test_getContourPoints(self):
        pass

    def test_getCompositePoints(self):
        pass


if __name__ == '__main__':
    unittest.main()



import unittest
from smufolib.stdUtils import (
    flatten,
    addTuples,
    isFloat,
    validateClassAttr
)

# pylint: disable=C0115, C0116, C0103


class StdUtils(unittest.TestCase):

    def test_flatten(self):
        pass

    def test_addTuples(self):
        pass

    def test_isFloat(self):
        pass

    def test_validateClassAttr(self):
        pass


if __name__ == '__main__':
    unittest.main()



import unittest
from smufolib.config import load

# pylint: disable=C0115, C0116, C0103


class Config(unittest.TestCase):
    @classmethod
    def SetUpClass(cls):
        # Create config test file
        pass

    @classmethod
    def TearDownClass(cls):
        # Delete config test file
        pass

    def test_load(self):
        # Should test:
            # - value parsing
            # - path selection
            # - file integrity (exsistence, type and contents)
        pass


if __name__ == '__main__':
    unittest.main()



import unittest
from smufolib.converters import (
    convertMeasurement, toDecimal, toUniHex, toUniName, toKebab, toNumber)

# pylint: disable=C0115, C0116, C0103


class Converters(unittest.TestCase):

    def test_convertMeasurement(self):
        self.assertEqual(convertMeasurement(
            125, convertTo='spaces', unitsPerEm=1000), 0.5)
        self.assertEqual(convertMeasurement(
            0.5, convertTo='units', unitsPerEm=1000), 125
        )

        with self.assertRaises(TypeError):
            convertMeasurement(
                (125,), convertTo='spaces', unitsPerEm=1000)
        with self.assertRaises(ValueError):
            convertMeasurement(
                125, convertTo='something else', unitsPerEm=1000)

    def test_toDecimal(self):
        for value in ('U+E00C', 'uE00C', 'uniE00C'):
            self.assertEqual(toDecimal(value), 57356)
            with self.assertRaises(ValueError):
                toDecimal(value[1:])
        with self.assertRaises(TypeError):
            toDecimal(57356)

    def test_toUniHex(self):
        self.assertEqual(toUniHex(57344), 'U+E000')
        with self.assertRaises(TypeError):
            toUniHex('57344')
        with self.assertRaises(ValueError):
            toUniHex(2000000)

    def test_toUniName(self):
        # for value in (57344, '57344', 'U+E000'):
        self.assertEqual(toUniName(57344), 'uniE000')
        self.assertEqual(toUniName('U+E000'), 'uniE000')
        self.assertEqual(toUniName(57344, short=True), 'uE000')
        with self.assertRaises(TypeError):
            toUniName([57344])
        with self.assertRaises(ValueError):
            toUniName('57344')
        with self.assertRaises(ValueError):
            toUniName(2000000)

    def test_toKebab(self):
        self.assertEqual(toKebab('helloWorld!'), 'hello-world!')
        # self.assertEqual(toKebab('setID'), 'set-id')
        with self.assertRaises(TypeError):
            toKebab(['485937'])

    def test_toNumber(self):
        self.assertEqual(toNumber('4598'), 4598)
        self.assertEqual(toNumber('0x4598'), 0x4598)
        self.assertEqual(toNumber('45.8'), 45.8)
        with self.assertRaises(AttributeError):
            toNumber(['485937'])
        with self.assertRaises(ValueError):
            toNumber('456h')


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python3
# coding: utf-8
"""
This script deletes SMuFL-specific metadata and glyph anchors from a UFO
font file.

To prevent unwanted data loss, items to delete *must* be specifically
included and may also be specifically exlcuded. If ``exclude='None'``,
``include='*'`` (all) will delete everything, essentially resetting the
font to a Non-SMuFL state. Individual attribute and anchor names may
otherwise be specified in both parameters as a single string or tuple
of any of the following values:

    Attributes
        ``'designSize'``
        ``'sizeRange'``
        ``'engravingDefaults'``
        ``'name'``
        ``'classes'``
        ``'description'``
        ``'spaces'``

    Anchors
        ``'splitStemUpSE'``
        ``'splitStemUpSW'``
        ``'splitStemDownNE'``
        ``'splitStemDownNW'``
        ``'stemUpSE'``
        ``'stemDownNW'``
        ``'stemUpNW'``
        ``'stemDownSW'``
        ``'nominalWidth'``
        ``'numeralTop'``
        ``'numeralBottom'``
        ``'cutOutNE'``
        ``'cutOutSE'``
        ``'cutOutSW'``
        ``'cutOutNW'``
        ``'graceNoteSlashSW'``
        ``'graceNoteSlashNE'``
        ``'graceNoteSlashNW'``
        ``'graceNoteSlashSE'``
        ``'repeatOffset'``
        ``'noteheadOrigin'``
        ``'opticalCenter'``

.. Warning:: This script will permanently delete data. Remember to
   always back up your file before running.

This script requires that SMufoLib be installed within its executive
environment. It may also be imported as a module and contains the
following public funcitons:

    * :func:`importID` – The scripts program function.
    * :func:`main` - Command line entry point.

"""
from collections.abc import Iterable
import argparse
from pathlib import Path

from tqdm import tqdm

from smufolib import Font, cli
from smufolib.objects.smufl import (
    ANCHOR_NAMES, FONT_ATTRIBUTES, GLYPH_ATTRIBUTES)

# Parameter defaults
EXCLUDE = None
VERBOSE = False

# pylint: disable=C0103


def cleanFont(font: Font | Path | str,
              include: Iterable,
              exclude: Iterable = EXCLUDE,
              verbose: bool = VERBOSE):
    """Delete :class:`~smufolib.smufl.Smufl` class attribute values.

    :param font: Object or path to
        target :class:`~smufolib.objects.font.Font`.
    :param include: items to be deleted. May be ``'*'`` (all), an
        individual attribute or anchor name as a :class:`str`
        or :class:`tuple` of several.
    :param exclude: Items to be preserved if `ìnclude='*'``. Defaults to
        :obj:`None`.
    :param verbose: Make output verbose. Defaults to :obj:`False`.

    """
    print("Processing...", end="\n\n")

    # Convert font path to object.
    font = font if isinstance(font, Font) else Font(font)

    # Define print function to be do-nothing if verbose=False.
    verboseprint = print if verbose else lambda *a, **k: None

    itemsToClean = _buildItemsDict(include, exclude)

    # Clean font attributes
    print("Cleaning font attributes...", end="\n\n")
    for attr in itemsToClean['fontAttributes']:
        if attr == 'engravingDefaults':
            font.smufl.engravingDefaults.clear()
        elif attr == 'spaces':
            setattr(font.smufl, attr, False)
        else:
            setattr(font.smufl, attr, None)

    print("Cleaning glyph items...")
    for glyph in font if verbose else tqdm(font):
        # Clean glyph attributes
        for index, attr in enumerate(itemsToClean['glyphAttributes']):
            if getattr(glyph.smufl, attr) is None:
                continue
            if index == 0:
                verboseprint("\nCleaning attributes from glyph:", glyph)
            setattr(glyph.smufl, attr, None)
            verboseprint(f"\t{attr}")

        # Clean Anchors
        if not any(a in itemsToClean['anchors'] for a in glyph.anchors):
            continue
        for anchor in glyph.anchors:
            if not anchor or anchor.name not in itemsToClean['anchors']:
                continue
            if anchor.index == 0:
                verboseprint("\nCleaning anchors from glyph:", glyph)
            glyph.removeAnchor(anchor.index)
            verboseprint(f"\t{anchor.name}")

    font.save()
    print("\nDone!")


def main():
    """Command line entry point."""
    args = _parseArgs()
    cleanFont(args.font,
              args.include,
              exclude=args.exclude,
              verbose=args.verbose)


def _buildItemsDict(include, exclude):
    # Build dict of attribute and anchor items to remove.

    itemsToClean = {}
    itemsToClean['fontAttributes'] = []
    itemsToClean['glyphAttributes'] = []
    itemsToClean['anchors'] = []

    if include == '*':
        include = FONT_ATTRIBUTES | GLYPH_ATTRIBUTES | ANCHOR_NAMES
    include = (include,) if isinstance(include, str) else include

    exclude = () if exclude is None else exclude
    exclude = (exclude,) if isinstance(exclude, str) else exclude

    for item in include:
        if item in exclude:
            continue
        if item in FONT_ATTRIBUTES:
            itemsToClean['fontAttributes'].append(item)
        elif item in GLYPH_ATTRIBUTES:
            itemsToClean['glyphAttributes'].append(item)
        elif item in ANCHOR_NAMES:
            itemsToClean['anchors'].append(item)
        else:
            raise ValueError(f"Invalid item: '{item}'.")

    return itemsToClean


def _parseArgs() -> argparse.Namespace:
    # Parse command line arguments and options.
    parser = argparse.ArgumentParser(
        parents=[cli.commonParser(
            'font',
            'include',
            exclude=EXCLUDE,
            verbose=VERBOSE)],
        description='Set annotation include from SMuFL metadata.')
    return parser.parse_args()


if __name__ == '__main__':
    main()



import unittest
from smufolib.normalizers import (
    normalizeFont,
    normalizeClasses,
    normalizeDescription,
    normalizeDesignSize,
    normalizeSizeRange,
    normalizeSmufl,
    normalizeSmuflName,
    normalizeEngravingDefaults,
    normalizeEngravingDefaultsAttr,
    normalizeRequest,
    normalizeRequestPath
)

# pylint: disable=C0115, C0116, C0103


class Normalizers(unittest.TestCase):
    def getFont_layers(self):
        font, _ = self.objectGenerator("font")
        for name in ["A", "B", "C", "D", "E"]:
            font.newLayer(name)
        return font

    def test_normalizeFont(self):
        self.assertEqual(normalizeFont(getFont_layers()), getFont_layers())

    def test_normalizeClasses(self):
        pass

    def test_normalizeDescription(self):
        pass

    def test_normalizeDesignSize(self):
        pass

    def test_normalizeSizeRange(self):
        pass

    def test_normalizeSmufl(self):
        pass

    def test_normalizeSmuflName(self):
        pass

    def test_normalizeEngravingDefaults(self):
        pass

    def test_normalizeEngravingDefaultsAttr(self):
        pass

    def test_normalizeRequest(self):
        pass

    def test_normalizeRequestPath(self):
        pass


if __name__ == '__main__':
    unittest.main()



import unittest
from smufolib.cli import commonParser

# pylint: disable=C0115, C0116, C0103


class CLI(unittest.TestCase):
    @classmethod
    def SetUpClass(cls):
        pass

    @classmethod
    def TearDownClass(cls):
        pass

    def test_commonParser(self):
        pass


if __name__ == '__main__':
    unittest.main()



import unittest
from smufolib import Smufl

# pylint: disable=C0115, C0116, C0103


class EngravingDefaults(unittest.TestCase):
    def test_clear:
        pass

    def test_items:
        pass

    def test_keys:
        pass

    def test_update:
        pass

    def test_values:
        pass

    def test_smufl:
        pass

    def test_font:
        pass

    def test_glyph:
        pass

    def test_layer:
        pass

    def test_arrowShaftThickness:
        pass

    def test_barlineSeparation:
        pass

    def test_beamSpacing:
        pass

    def test_beamThickness:
        pass

    def test_bracketThickness:
        pass

    def test_dashedBarlineDashLength:
        pass

    def test_dashedBarlineGapLength:
        pass

    def test_dashedBarlineThickness:
        pass
        def test_hairpinThickness:
        pass

    def test_hBarThickness:
        pass

    def test_legerLineExtension:
        pass

    def test_legerLineThickness:
        pass

    def test_lyricLineThickness:
        pass

    def test_octaveLineThickness:
        pass

    def test_pedalLineThickness:
        pass

    def test_repeatBarlineDotSeparation:
        pass

    def test_repeatEndingLineThickness:
        pass

    def test_slurEndpointThickness:
        pass

    def test_slurMidpointThickness:
        pass

    def test_staffLineThickness:
        pass

    def test_stemThickness:
        pass

    def test_subBracketThickness:
        pass

    def test_textFontFamily:
        pass

    def test_textEnclosureThickness:
        pass

    def test_thickBarlineThickness:
        pass

    def test_thinBarlineThickness:
        pass

    def test_thinThickBarlineSeparation:
        pass

    def test_tieEndpointThickness:
        pass

    def test_tieMidpointThickness:
        pass

    def test_tieMidpointThickness:
        pass

    def test_tupletBracketThickness:
        pass

    def test_round:
        pass

    def test_spaces:
        pass


if __name__ == '__main__':
    unittest.main()



import unittest
from smufolib import Smufl

# pylint: disable=C0115, C0116, C0103


class Smufl(unittest.TestCase):
    def test_font:
        pass

    def test_glyph:
        pass

    def test_layer:
        pass

    def test_designSize:
        pass

    def test_engravingDefaults:
        pass

    def test_sizeRange:
        pass

    def test_alternates:
        pass

    def test_anchors:
        pass

    def test_bBox:
        pass

    def test_codepoint:
        pass

    def test_componentGlyphs:
        pass

    def test_range:
        pass

    def test_advanceWidth:
        pass

    def test_version:
        pass

    def test_classes:
        pass

    def test_description:
        pass

    def test_name:
        pass

    def test_isLigature:
        pass

    def test_isMember:
        pass

    def test_isOptional:
        pass

    def test_isRecommended:
        pass

    def test_isSalt:
        pass

    def test_isSet:
        pass

    def test_round:
        pass

    def test_toSpaces:
        pass

    def test_toUnits:
        pass

    def test_spaces:
        pass

    def test_base:
        pass

    def test_findGlyph:
        pass

    def test_suffix:
        pass


if __name__ == '__main__':
    unittest.main()



import unittest
from smufolib import Smufl

# pylint: disable=C0115, C0116, C0103


class Range(unittest.TestCase):
    def test_smufl:
        pass

    def test_glyph:
        pass

    def test_font:
        pass

    def test_layer:
        pass

    def test_name:
        pass

    def test_description:
        pass

    def test_glyphs:
        pass

    def test_start:
        pass

    def test_end:
        pass


if __name__ == '__main__':
    unittest.main()
